@@ -59,6 +59,7 @@ import stat
 # Magic number 42 is used to connect to all radios found in 'settings.ini'.
 
 os.chdir(os.path.dirname(os.path.abspath(__file__)))  # go to .py script folder
+username = getpass.getuser()
 
 exit_app = False
 urllib3.disable_warnings()
@@ -68,17 +69,17 @@ urllib3.disable_warnings()
 
 def switch_dst_dir(container):  # if app runs in a container
 
-    username = getpass.getuser()
-    # print(username)
+    global username
+    print('Hello, ' + username)
     if container == 'SNAP':
         ghetto_folder = '//home//' + username + '//GhettoRecorder'
     else:
         ghetto_folder = '//tmp//GhettoRecorder'  # DOCKER
 
     source_ini = os.path.dirname(os.path.abspath(__file__)) + '//settings.ini'
-    source_script = os.path.dirname(os.path.abspath(__file__)) + '//startGhettoRecorder'
+    source_script = os.path.dirname(os.path.abspath(__file__)) + '//StartGhetto.sh'
     dst_ini = ghetto_folder + '//settings.ini'
-    dst_script = ghetto_folder + '//startGhettoRecorder'
+    dst_script = ghetto_folder + '//StartGhetto.sh'
 
     access_rights = 0o755
     try:
